resolve_windows_shortcut library
Contains functions and extensions that parse MS Shell Link (Windows Shorcut) files
Implemented based on the open spec of Shell Links.
Classes
Enums
- ShortcutResolverEntityType
- A file system entity type that can be resolved from a Shell Link.
Extensions
Constants
-
shellLinkGuidHexList
→ const List<
int> - Unique Identifier for Shell Link files in byte array form